## 5.0.1.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 5.0.1.0 (2023-05-16)

Bump `tzlocal` to `5.0.1` (#10188)

## 5.0.0.0 (2023-05-15)

Bump `tzlocal` to `5.0` (#10183)

## 4.3.0.0 (2023-03-19)

[stubsabot] Bump tzlocal to 4.3 (#9903)

Release: https://pypi.org/pypi/tzlocal/4.3
Diff: https://github.com/regebro/tzlocal/compare/4.2...4.3

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 2 files included in typeshed's stubs have been modified or renamed: `tzlocal/utils.py`, `tzlocal/windows_tz.py`.
 - Total lines of Python code added: 67.
 - Total lines of Python code deleted: 41.

## 4.2.2.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 4.2.2.2 (2022-11-14)

Comments explaining why `keyboard` and `tzlocal` are not run on multiple platforms (#9188)

## 4.2.2.1 (2022-10-23)

Remove tzlocal from pyright's exclude (#8969)

## 4.2.2 (2022-07-20)

Allowlist useless modules (#8340)

These are the ones I chose not to add from #8321

Fixes most of #8339

## 4.2.1 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 4.2.0 (2022-06-26)

[stubsabot] Bump tzlocal to 4.2 (#8184)

Co-authored-by: hauntsaninja <>

## 4.1.1 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 4.1.0 (2022-01-14)

Add get_localzone_name to tzlocal (#6912)

## 3.0.0 (2021-10-12)

Update remaining versions for third-party stubs (#6094)

Also remove the python2 markers of packages that don't list Python 2
as supported in the latest version.

Don't special case version '0.1'

Co-authored-by: Akuli <akuviljanen17@gmail.com>

